@@ -193,7 +193,7 @@ def sort_stream(
     if config.atomic:
         try:
             file_content = input_stream.read()
-            compile(file_content, content_source, "exec", 0, 1)
+            compile(file_content, content_source, "exec", flags=0, dont_inherit=True)
         except SyntaxError:
             if extension not in CYTHON_EXTENSIONS:
                 raise ExistingSyntaxErrors(content_source)
@@ -220,7 +220,7 @@ def sort_stream(
     if config.atomic:
         _internal_output.seek(0)
         try:
-            compile(_internal_output.read(), content_source, "exec", 0, 1)
+            compile(_internal_output.read(), content_source, "exec", flags=0, dont_inherit=True)
             _internal_output.seek(0)
         except SyntaxError:  # pragma: no cover
             if extension not in CYTHON_EXTENSIONS:
@@ -363,6 +363,9 @@ def _file_output_stream_context(filename: Union[str, Path], source_file: File) -
         yield output_stream
 
 
+# Ignore DeepSource cyclomatic complexity check for this function. It is one
+# the main entrypoints so sort of expected to be complex.
+# skipcq: PY-R1000
 def sort_file(
     filename: Union[str, Path],
     extension: Optional[str] = None,
@@ -442,9 +445,9 @@ def sort_file(
                                         file_input=source_file.stream.read(),
                                         file_output=output_stream.read(),
                                         file_path=actual_file_path,
-                                        output=None
-                                        if show_diff is True
-                                        else cast(TextIO, show_diff),
+                                        output=(
+                                            None if show_diff is True else cast(TextIO, show_diff)
+                                        ),
                                         color_output=config.color_output,
                                     )
                                     if show_diff or (
@@ -466,12 +469,9 @@ def sort_file(
                             if not config.quiet:
                                 print(f"Fixing {source_file.path}")
                     finally:
-                        try:  # Python 3.8+: use `missing_ok=True` instead of try except.
-                            if not config.overwrite_in_place:  # pragma: no branch
-                                tmp_file = _tmp_file(source_file)
-                                tmp_file.unlink()
-                        except FileNotFoundError:
-                            pass  # pragma: no cover
+                        if not config.overwrite_in_place:  # pragma: no branch
+                            tmp_file = _tmp_file(source_file)
+                            tmp_file.unlink(missing_ok=True)
                 else:
                     changed = sort_stream(
                         input_stream=source_file.stream,
