@@ -1,4 +1,5 @@
 """Defines parsing functions used by isort for parsing import definitions"""
+
 import re
 from collections import OrderedDict, defaultdict
 from functools import partial
@@ -475,9 +476,9 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                         import_from, {}
                     )
                     existing_comment = nested_from_comments.get(just_imports[0], "")
-                    nested_from_comments[
-                        just_imports[0]
-                    ] = f"{existing_comment}{'; ' if existing_comment else ''}{'; '.join(comments)}"
+                    nested_from_comments[just_imports[0]] = (
+                        f"{existing_comment}{'; ' if existing_comment else ''}{'; '.join(comments)}"
+                    )
                     comments = []
 
                 if comments and attach_comments_to is None:
@@ -519,7 +520,11 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                 if comments and attach_comments_to is not None:
                     attach_comments_to.extend(comments)
 
-                if "," in import_string.split(just_imports[-1])[-1]:
+                if (
+                    just_imports
+                    and just_imports[-1]
+                    and "," in import_string.split(just_imports[-1])[-1]
+                ):
                     trailing_commas.add(import_from)
             else:
                 if comments and attach_comments_to is not None:
