@@ -1,9 +1,10 @@
 import json
 import os
+import pathlib
+import shutil
 import subprocess
 from datetime import datetime
 
-import py
 import pytest
 from hypothesis import given
 from hypothesis import strategies as st
@@ -1079,8 +1080,7 @@ def test_identify_imports_main(tmpdir, capsys):
     assert len(out.split("\n")) == 3
 
 
-def test_gitignore(capsys, tmpdir: py.path.local):
-
+def test_gitignore(capsys, tmp_path: pathlib.Path):
     import_content = """
 import b
 import a
@@ -1093,15 +1093,15 @@ import a
             pass
         return capsys.readouterr()
 
-    subprocess.run(["git", "init", str(tmpdir)])
-    python_file = tmpdir.join("has_imports.py")
-    python_file.write(import_content)
-    tmpdir.join("no_imports.py").write("...")
+    subprocess.run(["git", "init", str(tmp_path)])
+    python_file = tmp_path / "has_imports.py"
+    python_file.write_text(import_content)
+    (tmp_path / "no_imports.py").write_text("...")
 
     out, error = main_check([str(python_file), "--skip-gitignore", "--filter-files", "--check"])
     assert "has_imports.py" in error and "no_imports.py" not in error
 
-    tmpdir.join(".gitignore").write("has_imports.py")
+    (tmp_path / ".gitignore").write_text("has_imports.py")
 
     out, error = main_check([str(python_file), "--check"])
     assert "has_imports.py" in error and "no_imports.py" not in error
@@ -1110,22 +1110,22 @@ import a
     assert "Skipped" in out
 
     # Should work with nested directories
-    tmpdir.mkdir("nested_dir")
-    tmpdir.join(".gitignore").write("nested_dir/has_imports.py")
-    subfolder_file = tmpdir.join("nested_dir/has_imports.py")
-    subfolder_file.write(import_content)
+    (tmp_path / "nested_dir").mkdir()
+    (tmp_path / ".gitignore").write_text("nested_dir/has_imports.py")
+    subfolder_file = tmp_path / "nested_dir/has_imports.py"
+    subfolder_file.write_text(import_content)
 
-    out, error = main_check([str(tmpdir), "--skip-gitignore", "--filter-files", "--check"])
+    out, error = main_check([str(tmp_path), "--skip-gitignore", "--filter-files", "--check"])
     assert "has_imports.py" in error and "nested_dir/has_imports.py" not in error
 
     # Should work with relative path
     currentdir = os.getcwd()
-    os.chdir(tmpdir)
+    os.chdir(tmp_path)
 
     out, error = main_check([".", "--skip-gitignore", "--filter-files", "--check"])
     assert "has_imports.py" in error and "nested_dir/has_imports.py" not in error
 
-    tmpdir.join(".gitignore").write(
+    (tmp_path / ".gitignore").write_text(
         """
 nested_dir/has_imports.py
 has_imports.py
@@ -1138,17 +1138,18 @@ has_imports.py
 
     # Should work with multiple git projects
 
-    tmpdir.join(".git").remove()
-    tmpdir.join(".gitignore").remove()
+    shutil.rmtree(tmp_path / ".git")
+    (tmp_path / ".gitignore").unlink()
 
     # git_project0
     # | has_imports_ignored.py ignored
     # | has_imports.py should check
-    git_project0 = tmpdir.mkdir("git_project0")
+    git_project0 = tmp_path / "git_project0"
+    git_project0.mkdir()
     subprocess.run(["git", "init", str(git_project0)])
-    git_project0.join(".gitignore").write("has_imports_ignored.py")
-    git_project0.join("has_imports_ignored.py").write(import_content)
-    git_project0.join("has_imports.py").write(import_content)
+    (git_project0 / ".gitignore").write_text("has_imports_ignored.py")
+    (git_project0 / "has_imports_ignored.py").write_text(import_content)
+    (git_project0 / "has_imports.py").write_text(import_content)
 
     # git_project1
     # | has_imports.py should check
@@ -1157,19 +1158,23 @@ has_imports.py
     #   | has_imports.py should check
     # | nested_dir_ignored ignored
     #   | has_imports.py ignored from folder
-    git_project1 = tmpdir.mkdir("git_project1")
+    git_project1 = tmp_path / "git_project1"
+    git_project1.mkdir()
     subprocess.run(["git", "init", str(git_project1)])
-    git_project1.join(".gitignore").write(
+    (git_project1 / ".gitignore").write_text(
         """
 nested_dir/has_imports_ignored.py
 nested_dir_ignored
 """
     )
-    git_project1.join("has_imports.py").write(import_content)
-    nested_dir = git_project1.mkdir("nested_dir")
-    nested_dir.join("has_imports.py").write(import_content)
-    nested_dir.join("has_imports_ignored.py").write(import_content)
-    git_project1.mkdir("nested_dir_ignored").join("has_imports.py").write(import_content)
+    (git_project1 / "has_imports.py").write_text(import_content)
+    nested_dir = git_project1 / "nested_dir"
+    nested_dir.mkdir()
+    (nested_dir / "has_imports.py").write_text(import_content)
+    (nested_dir / "has_imports_ignored.py").write_text(import_content)
+    nested_ignored_dir = git_project1 / "nested_dir_ignored"
+    nested_ignored_dir.mkdir()
+    (nested_ignored_dir / "has_imports.py").write_text(import_content)
 
     should_check = [
         "/has_imports.py",
@@ -1179,27 +1184,28 @@ nested_dir_ignored
         "/git_project1/nested_dir/has_imports.py",
     ]
 
-    out, error = main_check([str(tmpdir), "--skip-gitignore", "--filter-files", "--check"])
+    out, error = main_check([str(tmp_path), "--skip-gitignore", "--filter-files", "--check"])
 
     if os.name == "nt":
         should_check = [sc.replace("/", "\\") for sc in should_check]
 
-    assert all(f"{str(tmpdir)}{file}" in error for file in should_check)
+    assert all(f"{tmp_path}{file}" in error for file in should_check)
 
-    out, error = main_check([str(tmpdir), "--skip-gitignore", "--filter-files"])
+    out, error = main_check([str(tmp_path), "--skip-gitignore", "--filter-files"])
 
-    assert all(f"{str(tmpdir)}{file}" in out for file in should_check)
+    assert all(f"{tmp_path}{file}" in out for file in should_check)
 
     # Should work when git project contains symlinks
 
     if os.name != "nt":
-        git_project0.join("has_imports_ignored.py").write(import_content)
-        git_project0.join("has_imports.py").write(import_content)
-        tmpdir.join("has_imports.py").write(import_content)
-        tmpdir.join("nested_dir").join("has_imports.py").write(import_content)
-        git_project0.join("ignore_link.py").mksymlinkto(tmpdir.join("has_imports.py"))
-        git_project0.join("ignore_link").mksymlinkto(tmpdir.join("nested_dir"))
-        git_project0.join(".gitignore").write("ignore_link.py\nignore_link", mode="a")
+        (git_project0 / "has_imports_ignored.py").write_text(import_content)
+        (git_project0 / "has_imports.py").write_text(import_content)
+        (tmp_path / "has_imports.py").write_text(import_content)
+        (tmp_path / "nested_dir" / "has_imports.py").write_text(import_content)
+        (git_project0 / "ignore_link.py").symlink_to(tmp_path / "has_imports.py")
+        (git_project0 / "ignore_link").symlink_to(tmp_path / "nested_dir")
+        gitignore = git_project0 / ".gitignore"
+        gitignore.write_text(gitignore.read_text() + "ignore_link.py\nignore_link")
 
         out, error = main_check(
             [str(git_project0), "--skip-gitignore", "--filter-files", "--check"]
@@ -1207,11 +1213,11 @@ nested_dir_ignored
 
         should_check = ["/git_project0/has_imports.py"]
 
-        assert all(f"{str(tmpdir)}{file}" in error for file in should_check)
+        assert all(f"{tmp_path}{file}" in error for file in should_check)
 
         out, error = main_check([str(git_project0), "--skip-gitignore", "--filter-files"])
 
-        assert all(f"{str(tmpdir)}{file}" in out for file in should_check)
+        assert all(f"{tmp_path}{file}" in out for file in should_check)
 
 
 def test_multiple_configs(capsys, tmpdir):
